#!/bin/bash
#
# Master script for Distributed AIDE Runtime Controller
#
# Author: Jacob Martinson <martinson.jacob at gmail.com>
#

# set vars to talk to ssh-agent
. ~/.bashrc

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

if [ -z "$DARCHOME" ]; then
  echo "DARCHOME variable is not set."
  exit 1
fi

if [ ! -d "$DARCHOME" ]; then
  echo "DARCHOME directory does not exist: $DARCHOME"
  exit 1
fi

. ${DARCHOME}/config.sh

umask 077

if [ -f $lockfile ]; then
  echo "Will not run with lockfile in place: $lockfile"
  exit 1
else
  echo $$ > $lockfile
fi

# clean old reports out of $tmpdir
# there should only be files in here if we were killed in 
# mid-process on the last run
rm -f ${tmpdir}/*

. ${DARCHOME}/hostdefs.sh


function reportnothing(){
mail -s "[DARC] Nothing to report" $rcptlist <<ENDMSG

There were no differences found at $timestamp.

ENDMSG
}

function send_unified_report(){
  timestamp=`date +%Y%m%d_%H%M`
  unifiedreport=${reportdir}/unifiedreport.${timestamp}
  for x in `ls $tmpdir | grep 'report' 2>&1 `
  do
    cat ${tmpdir}/$x >> $unifiedreport
    echo >> $unifiedreport
    mv $tmpdir/$x $reportdir
  done
  mail -s "[DARC] FS Integrity Violations" $rcptlist < $unifiedreport

}

# generate single report
ls $tmpdir | grep 'report' >/dev/null 2>&1
if [ $? -ne 0 ]; then
  echo "No differences found at $timestamp "
  reportnothing
else
  echo "Sending unified report."
  send_unified_report
fi

rm $lockfile
