#!/bin/bash -x
#
# Author: Jacob Martinson <martinson.jacob at gmail.com>
#
#

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

if [ -z "$DARCHOME" ]; then
  echo "DARCHOME variable is not set."
  exit 1
fi

if [ ! -d "$DARCHOME" ]; then
  echo "DARCHOME directory does not exist: $DARCHOME"
  exit 1
fi

. ${DARCHOME}/config.sh

if [ -z $host ]; then
  echo "'host' variable not found in env."; exit 1
fi

if [ -z $binary ]; then
  echo "'binary' variable not found in env."; exit 1
fi

if [ ! -f $binary ]; then
  echo "File does not exist: $binary"; exit 1
fi

if [ -z $username ]; then
  echo "'username' variable not found in env."; exit 1
fi

if [ -z $sshport ]; then
  echo "'sshport' variable not found in env."; exit 1
fi

if [ -z $id_dsa ]; then
  echo "'id_dsa' variable not found in env."; exit 1
fi

if [ ! -f $id_dsa ]; then
  echo "File does not exist: $id_dsa"; exit 1
fi

config=${confdir}/baseconfig.${host}
if [ ! -f "$config" ]; then
  echo "Basconfig file does not exist: $config"
  exit 1
fi

umask 077

echo "### `date`" 
echo "### Starting $0" 

if [ ! -f "$baseline" ]; then
  echo "Baseline database does not exist: $baseline"
  exit 1
fi

# PATH NAME FOR AIDE BINARY
remotepath=/tmp/aide`date '+%s'`

# PUT BINARY ON TARGET
echo "sftp input:"
cat <<EOF
put $binary $remotepath
chmod 700 $remotepath
EOF

sftp -oIdentityFile=$id_dsa -oPort=$sshport ${username}@${host} \
  >>$log 2>&1 <<EOF
put $binary $remotepath
chmod 700 $remotepath
EOF

# GENERATE A DB
sshcmd="ssh -v -t -i $id_dsa -p $sshport ${username}@${host} sudo nice -n 19 $remotepath -i --config='-'"
$sshcmd > $newdb <<EOF
database_out=stdout
`cat ${config}`
EOF

# REMOVE BINARY FROM TARGET
echo "sftp input: rm $remotepath"
sftp -oIdentityFile=$id_dsa -oPort=$sshport ${username}@${host} 2>&1 <<EOF
rm $remotepath
EOF

## TRIM AIDE STDERR THAT COMES OVER SSH
mv $newdb ${newdb}.tmp
cat ${newdb}.tmp | egrep -v '^$|AIDE, version|###' > $newdb
rm ${newdb}.tmp

# GENERATE STANDARD REPORT
cat >$report <<EOF

##############################################################################
# $host aide report:

EOF

# check baseline and newdb databases for zero size, can happen if
# there are problems communicating with remote host, if there are 
# bugs in these scripts, etc.
EMPTYDB=0
if [ ! -s "$baseline" ]; then
  EMPTYDB=1
  cat >>$report <<EOF

Baseline database is empty:
$baseline

EOF
fi

if [ ! -s "$newdb" ]; then
  EMPTYDB=1
  cat >>$report <<EOF

New database is empty:
$newdb

EOF
fi

# if database files are not empty
if [ $EMPTYDB -eq 0 ]; then
  aide --compare --config="-" >>$report <<EOF
database=file://${baseline}
database_new=file://${newdb}
`cat ${confdir}/baseconfig.${host}`
EOF

  # check report for differences found
  grep 'AIDE found differences ' $report >/dev/null 2>&1
  
  # if $? != 0, aide found NO filesystem changes
  if [ $? -ne 0 ]; then
    # NO filesystem changes, just mv the report to $reportdir
	# and it won't be picked up for the unified report
    mv $report ${reportdir}
  fi
fi


echo "### `date`" 
echo "### Finished $0" 
echo 
echo 

